==> v1.2.14-3.tar.gz: kanboard/README.md <==
# [kanboard](https://gitea.rknet.org/docker/kanboard)

[![Build Status](https://img.shields.io/drone/build/docker/kanboard?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/docker/kanboard)
[![Docker Hub](https://img.shields.io/badge/docker-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/xoxys/kanboard)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/docker/kanboard/src/branch/master/LICENSE)

> __WARNING__: since release v1.2.1102 this image is a rootless image and may BREAK your setup!

Kanboard is project management software that focuses on the Kanban methodology.

## Usage

Here are some example snippets to help you get started creating a container. This repository is just a wrapper to build a community docker image from [Kanboard](https://github.com/kanboard/kanboard) releases.

> **WARNING**: For production usage you should secure your database and NOT use the default credentials!

### Docker

```Shell
docker create \
  --name=kanboard \
  -p 80:8080 \
  xoxys/kanboard
```

### Docker Compose

Compatible with docker-compose v2 schemas.

```Yaml
---
version: '3'

services:
  kanboard:
    container_name: kanboard
    image: xoxys/kanboard:latest
    ports:
      - "80:8080"
    volumes:
      - kanboard_data:/var/www/app/data
      - kanboard_plugins:/var/www/app/plugins
    environment:
      KANBOARD_PLUGIN_INSTALLER: "true"

volumes:
  kanboard_data:
    driver: local
  kanboard_plugins:
    driver: local
```

## Environment variables

### Kanboard

```Shell
KANBOARD_PLUGIN_INSTALLER=false
KANBOARD_CACHE_DRIVER=memory
KANBOARD_MAIL_CONFIGURATION=true
KANBOARD_MAIL_FROM=
KANBOARD_MAIL_TRANSPORT=mail
KANBOARD_MAIL_SMTP_HOSTNAME=
KANBOARD_MAIL_SMTP_PORT=25
KANBOARD_MAIL_SMTP_USERNAME=
KANBOARD_MAIL_SMTP_PASSWORD=
KANBOARD_MAIL_SMTP_ENCRYPTION=null
KANBOARD_MAIL_SENDMAIL_COMMAND=/usr/sbin/sendmail -bs
KANBOARD_DB_RUN_MIGRATIONS=true
KANBOARD_DB_DRIVER=sqlite
KANBOARD_DB_USERNAME=root
KANBOARD_DB_PASSWORD=root
KANBOARD_DB_HOSTNAME=localhost
KANBOARD_DB_NAME=kanboard
KANBOARD_DB_PORT=null
KANBOARD_DB_SSL_KEY=null
KANBOARD_DB_SSL_CERT=null
KANBOARD_DB_SSL_CA=null
KANBOARD_DB_VERIFY_SERVER_CERT=null
KANBOARD_DB_TIMEOUT=null
KANBOARD_LDAP_AUTH=false
KANBOARD_LDAP_SERVER=
KANBOARD_LDAP_PORT=389
KANBOARD_LDAP_SSL_VERIFY=true
KANBOARD_LDAP_START_TLS=false
KANBOARD_LDAP_USERNAME_CASE_SENSITIVE=false
KANBOARD_LDAP_BIND_TYPE=anonymous
KANBOARD_LDAP_USERNAME=null
KANBOARD_LDAP_PASSWORD=null
KANBOARD_LDAP_USER_BASE_DN=
KANBOARD_LDAP_USER_FILTER=
KANBOARD_LDAP_USER_ATTRIBUTE_USERNAME=uid
KANBOARD_LDAP_USER_ATTRIBUTE_FULLNAME=cn
KANBOARD_LDAP_USER_ATTRIBUTE_EMAIL=mail
KANBOARD_LDAP_USER_ATTRIBUTE_GROUPS=memberof
KANBOARD_LDAP_USER_ATTRIBUTE_PHOTO=
KANBOARD_LDAP_USER_ATTRIBUTE_LANGUAGE=
KANBOARD_LDAP_USER_CREATION=true
KANBOARD_LDAP_GROUP_ADMIN_DN=
KANBOARD_LDAP_GROUP_MANAGER_DN=
KANBOARD_LDAP_GROUP_PROVIDER=false
KANBOARD_LDAP_GROUP_BASE_DN=
KANBOARD_LDAP_GROUP_FILTER=
KANBOARD_LDAP_GROUP_USER_FILTER=
KANBOARD_LDAP_GROUP_ATTRIBUTE_NAME=cn
KANBOARD_REVERSE_PROXY_AUTH=false
KANBOARD_REVERSE_PROXY_USER_HEADER=REMOTE_USER
KANBOARD_REVERSE_PROXY_DEFAULT_ADMIN=
KANBOARD_REVERSE_PROXY_DEFAULT_DOMAIN=
KANBOARD_REMEMBER_ME_AUTH=true
KANBOARD_MARKDOWN_ESCAPE_HTML=true
KANBOARD_API_AUTHENTICATION_HEADER=
KANBOARD_ENABLE_URL_REWRITE=false
KANBOARD_HIDE_LOGIN_FORM=false
KANBOARD_DISABLE_LOGOUT=false
KANBOARD_BRUTEFORCE_CAPTCHA=3
KANBOARD_BRUTEFORCE_LOCKDOWN=6
KANBOARD_BRUTEFORCE_LOCKDOWN_DURATION=15
KANBOARD_SESSION_DURATION=0
KANBOARD_HTTP_PROXY_HOSTNAME=
KANBOARD_HTTP_PROXY_PORT=3128
KANBOARD_HTTP_PROXY_USERNAME=
KANBOARD_HTTP_PROXY_PASSWORD=
KANBOARD_HTTP_PROXY_EXCLUDE=localhost
KANBOARD_HTTP_VERIFY_SSL_CERTIFICATE=true
KANBOARD_TOTP_ISSUER=Kanboard
KANBOARD_EXTERNAL_AUTH_EXCLUDE_FIELDS=username
```

### PHP

```Shell
PHP_EXPOSE_PHP=Off
PHP_MAX_EXECUTION_TIME=30
PHP_MAX_INPUT_TIME=60
PHP_MEMORY_LIMIT=50M
PHP_ERROR_REPORTING=E_ALL & ~E_DEPRECATED & ~E_STRICT
PHP_DISPLAY_ERRORS=Off
PHP_DISPLAY_STARTUP_ERRORS=Off
PHP_LOG_ERRORS=On
PHP_LOG_ERRORS_MAX_LEN=1024
PHP_IGNORE_REPEATED_ERRORS=Off
PHP_IGNORE_REPEATED_SOURCE=Off
PHP_REPORT_MEMLEAKS=On
PHP_HTML_ERRORSOn
PHP_ERROR_LOG=/proc/self/fd/2
PHP_POST_MAX_SIZE=8M
PHP_FILE_UPLOADS=Off
PHP_UPLOAD_MAX_FILESIZE=2M
PHP_MAX_FILE_UPLOADS=2
PHP_ALLOW_URL_FOPEN=On
PHP_ALLOW_URL_INCLUDE=Off
PHP_DATE_TIMEZONE=Europe/Berlin
PHP_SQL_SAFE_MODE=On
```

## License

This project is licensed under the MIT License - see the [LICENSE](https://gitea.rknet.org/docker/kanboard/src/branch/master/LICENSE) file for details.

## Maintainers and Contributors

[Robert Kaussow](https://gitea.rknet.org/xoxys)

==> v1.2.16-1.tar.gz: kanboard/README.md <==
# kanboard

Custom image for Kanboard Kanban project management

[![Build Status](https://img.shields.io/drone/build/docker/kanboard?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/docker/kanboard)
[![Docker Hub](https://img.shields.io/badge/dockerhub-latest-blue.svg?logo=docker&logoColor=white)](https://hub.docker.com/r/thegeeklab/kanboard)
[![Quay.io](https://img.shields.io/badge/quay-latest-blue.svg?logo=docker&logoColor=white)](https://quay.io/repository/thegeeklab/kanboard)
[![Source: Gitea](https://img.shields.io/badge/source-gitea-blue.svg?logo=gitea&logoColor=white)](https://gitea.rknet.org/docker/kanboard)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/docker/kanboard/src/branch/master/LICENSE)

> **WARNING**: Since release v1.2.1102 this image is a rootless image and may BREAK your setup!

Custom rootless Docker image for Kanboard, a project management software that focuses on the Kanban methodology.

## Usage

Here are some example snippets to help you get started creating a container. This repository is just a wrapper to build a community docker image from [Kanboard](https://github.com/kanboard/kanboard) releases.

> **WARNING**: For production usage you should secure your database and NOT use the default credentials!

### Docker

```Shell
docker create \
  --name=kanboard \
  -p 80:8080 \
  thegeeklab/kanboard
```

### Docker Compose

Compatible with docker-compose v2 schemas.

```Yaml
---
version: '3'

services:
  kanboard:
    container_name: kanboard
    image: thegeeklab/kanboard:latest
    ports:
      - "80:8080"
    volumes:
      - kanboard_data:/var/www/app/data
      - kanboard_plugins:/var/www/app/plugins
    environment:
      KANBOARD_PLUGIN_INSTALLER: "true"

volumes:
  kanboard_data:
    driver: local
  kanboard_plugins:
    driver: local
```

## Environment variables

### Kanboard

```Shell
KANBOARD_PLUGIN_INSTALLER=false
KANBOARD_CACHE_DRIVER=memory
KANBOARD_MAIL_FROM=
KANBOARD_MAIL_TRANSPORT=mail
KANBOARD_MAIL_SMTP_HOSTNAME=
KANBOARD_MAIL_SMTP_PORT=25
KANBOARD_MAIL_SMTP_USERNAME=
KANBOARD_MAIL_SMTP_PASSWORD=
KANBOARD_MAIL_SMTP_ENCRYPTION=null
KANBOARD_MAIL_SENDMAIL_COMMAND=/usr/sbin/sendmail -bs
KANBOARD_DB_RUN_MIGRATIONS=true
KANBOARD_DB_DRIVER=sqlite
KANBOARD_DB_USERNAME=root
KANBOARD_DB_PASSWORD=root
KANBOARD_DB_HOSTNAME=localhost
KANBOARD_DB_NAME=kanboard
KANBOARD_DB_PORT=null
KANBOARD_DB_SSL_KEY=null
KANBOARD_DB_SSL_CERT=null
KANBOARD_DB_SSL_CA=null
KANBOARD_DB_VERIFY_SERVER_CERT=null
KANBOARD_DB_TIMEOUT=null
KANBOARD_LDAP_AUTH=false
KANBOARD_LDAP_SERVER=
KANBOARD_LDAP_PORT=389
KANBOARD_LDAP_SSL_VERIFY=true
KANBOARD_LDAP_START_TLS=false
KANBOARD_LDAP_USERNAME_CASE_SENSITIVE=false
KANBOARD_LDAP_BIND_TYPE=anonymous
KANBOARD_LDAP_USERNAME=null
KANBOARD_LDAP_PASSWORD=null
KANBOARD_LDAP_USER_BASE_DN=
KANBOARD_LDAP_USER_FILTER=
KANBOARD_LDAP_USER_ATTRIBUTE_USERNAME=uid
KANBOARD_LDAP_USER_ATTRIBUTE_FULLNAME=cn
KANBOARD_LDAP_USER_ATTRIBUTE_EMAIL=mail
KANBOARD_LDAP_USER_ATTRIBUTE_GROUPS=memberof
KANBOARD_LDAP_USER_ATTRIBUTE_PHOTO=
KANBOARD_LDAP_USER_ATTRIBUTE_LANGUAGE=
KANBOARD_LDAP_USER_CREATION=true
KANBOARD_LDAP_GROUP_ADMIN_DN=
KANBOARD_LDAP_GROUP_MANAGER_DN=
KANBOARD_LDAP_GROUP_PROVIDER=false
KANBOARD_LDAP_GROUP_BASE_DN=
KANBOARD_LDAP_GROUP_FILTER=
KANBOARD_LDAP_GROUP_USER_FILTER=
KANBOARD_LDAP_GROUP_ATTRIBUTE_NAME=cn
KANBOARD_REVERSE_PROXY_AUTH=false
KANBOARD_REVERSE_PROXY_USER_HEADER=REMOTE_USER
KANBOARD_REVERSE_PROXY_DEFAULT_ADMIN=
KANBOARD_REVERSE_PROXY_DEFAULT_DOMAIN=
KANBOARD_REMEMBER_ME_AUTH=true
KANBOARD_MARKDOWN_ESCAPE_HTML=true
KANBOARD_API_AUTHENTICATION_HEADER=
KANBOARD_ENABLE_URL_REWRITE=false
KANBOARD_HIDE_LOGIN_FORM=false
KANBOARD_DISABLE_LOGOUT=false
KANBOARD_BRUTEFORCE_CAPTCHA=3
KANBOARD_BRUTEFORCE_LOCKDOWN=6
KANBOARD_BRUTEFORCE_LOCKDOWN_DURATION=15
KANBOARD_SESSION_DURATION=0
KANBOARD_HTTP_PROXY_HOSTNAME=
KANBOARD_HTTP_PROXY_PORT=3128
KANBOARD_HTTP_PROXY_USERNAME=
KANBOARD_HTTP_PROXY_PASSWORD=
KANBOARD_HTTP_PROXY_EXCLUDE=localhost
KANBOARD_HTTP_VERIFY_SSL_CERTIFICATE=true
KANBOARD_TOTP_ISSUER=Kanboard
KANBOARD_EXTERNAL_AUTH_EXCLUDE_FIELDS=username
```

### PHP

```Shell
PHP_EXPOSE_PHP=Off
PHP_MAX_EXECUTION_TIME=30
PHP_MAX_INPUT_TIME=60
PHP_MEMORY_LIMIT=50M
PHP_ERROR_REPORTING=E_ALL & ~E_DEPRECATED & ~E_STRICT
PHP_DISPLAY_ERRORS=Off
PHP_DISPLAY_STARTUP_ERRORS=Off
PHP_LOG_ERRORS=On
PHP_LOG_ERRORS_MAX_LEN=1024
PHP_IGNORE_REPEATED_ERRORS=Off
PHP_IGNORE_REPEATED_SOURCE=Off
PHP_REPORT_MEMLEAKS=On
PHP_HTML_ERRORSOn
PHP_ERROR_LOG=/proc/self/fd/2
PHP_POST_MAX_SIZE=8M
PHP_FILE_UPLOADS=Off
PHP_UPLOAD_MAX_FILESIZE=2M
PHP_MAX_FILE_UPLOADS=2
PHP_ALLOW_URL_FOPEN=On
PHP_ALLOW_URL_INCLUDE=Off
PHP_DATE_TIMEZONE=Europe/Berlin
PHP_SQL_SAFE_MODE=On
```

## License

This project is licensed under the MIT License - see the [LICENSE](https://gitea.rknet.org/docker/kanboard/src/branch/master/LICENSE) file for details.
